@@ -15,7 +15,7 @@ Example
     from gevent import monkey
     monkey.patch_all()
 
-    from gsmtpd import SMTPServer
+    from gsmtpd.server import SMTPServer
 
     class PrintSMTPServer(SMTPServer):
 
@@ -31,8 +31,6 @@ __title__ = 'gsmtpd'
 __version__ = '0.1.9.3'
 __author__ = 'Meng Zhuo <mengzhuo1203@gmail.com>'
 
-from .server import SMTPServer, DebuggingServer, PureProxy
-
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
 try:  # Python 2.7+
