@@ -265,6 +265,9 @@ class SMTPChannel(object):
     def handle_read(self):
         try:
             data = self.conn.recv(self.ac_in_buffer_size)
+            if len(data) == 0:
+                # issues 2 TCP connect closed will send a 0 size pack
+                self.close_when_done()
         except socket.error:
             self.handle_error()
             return
