@@ -8,7 +8,7 @@ from gevent import monkey
 monkey.patch_all()
 
 import smtplib
-from gsmtpd import SMTPServer
+from gsmtpd.server import SMTPServer
 from greentest import TestCase
 from .utils import connect, run
 
@@ -36,6 +36,14 @@ class SMTPServerTestCase(TestCase):
                   '127.0.0.1', self.server.server_port)
         assert task[0] == 220
 
+    @connect
+    def test_broken_client(self):
+        self.sm.sock.close()
+        self.dup_sm = smtplib.SMTP()
+        # if broken blocks this testcase can't processed
+        self.dup_sm.connect('127.0.0.1', self.server.server_port)
+        self.assertEqual(self.dup_sm.ehlo()[0], 250)
+
     @connect
     def test_HELO(self):
         
